@@ -5,7 +5,7 @@ from server.models import TestDiff
 
 class ModelDiffTestCase(TestCase):
     def setUp(self):
-        self.obj = TestDiff(name='Foo')
+        self.obj = TestDiff(name="Foo")
         self.obj.save()
 
     def _no_change(self):
@@ -13,14 +13,14 @@ class ModelDiffTestCase(TestCase):
         self.assertEqual(list(self.obj.changed_fields), [])
 
     def test_no_change(self):
-        self.assertEqual(self.obj.name, 'Foo')
+        self.assertEqual(self.obj.name, "Foo")
         self._no_change()
 
     def test_name_change(self):
-        self.obj.name = 'Bar'
-        self.assertEqual(self.obj.name, 'Bar')
+        self.obj.name = "Bar"
+        self.assertEqual(self.obj.name, "Bar")
         self.assertEqual(self.obj.has_changed, True)
-        self.assertTrue('name' in self.obj.changed_fields)
+        self.assertTrue("name" in self.obj.changed_fields)
 
         self.assertFalse(self.obj.recorded_name_change)
         self.obj.save()
@@ -31,7 +31,7 @@ class ModelDiffTestCase(TestCase):
         self.obj.number = 100
         self.assertEqual(self.obj.number, 100)
         self.assertEqual(self.obj.has_changed, True)
-        self.assertTrue('number' in self.obj.changed_fields)
+        self.assertTrue("number" in self.obj.changed_fields)
 
         self.obj.save()
         self._no_change()
@@ -41,14 +41,17 @@ class ModelDiffTestCase(TestCase):
         obj.save()
         obj.number = 100
 
-        self.assertEqual(obj.initial['number'], 1)
+        self.assertEqual(obj.initial["number"], 1)
 
     def test_string_to_int(self):
         tm = TestDiff(name="Sally", number=1)
         tm.save()
-        tm.number = '2'
+        tm.number = "2"
 
-        self.assertDictEqual({"number": (1, 2)}, tm._get_diff(), )
+        self.assertDictEqual(
+            {"number": (1, 2)},
+            tm._get_diff(),
+        )
 
     def test_jsonfield_change(self):
         tm = TestDiff(a_json_field={"hi": "bye"})
@@ -61,3 +64,9 @@ class ModelDiffTestCase(TestCase):
         tm.save()
         self.assertFalse(tm.is_creation)
 
+    def test_deferred_recursion_error(self):
+        """
+        Regression test: in some cases, deferring a field has caused infinite recursion
+        """
+        objects = TestDiff.objects.all().only("number")
+        self.assertEqual(1, len(objects))
